# coding: utf-8

"""
    Zitadel SDK

    The Zitadel SDK is a convenience wrapper around the Zitadel APIs to assist you in integrating with your Zitadel environment. This SDK enables you to handle resources, settings, and configurations within the Zitadel platform.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBytes, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from zitadel_client.models.session_service_factors import SessionServiceFactors
from zitadel_client.models.session_service_user_agent import SessionServiceUserAgent
from typing import Optional, Set
from typing_extensions import Self

class SessionServiceSession(BaseModel):
    """
    SessionServiceSession
    """ # noqa: E501
    id: Optional[StrictStr] = Field(default=None, description="\"id of the session\"")
    creation_date: Optional[datetime] = Field(default=None, description="\"time when the session was created\"", alias="creationDate")
    change_date: Optional[datetime] = Field(default=None, description="\"time when the session was last updated\"", alias="changeDate")
    sequence: Optional[StrictStr] = Field(default=None, description="\"sequence of the session\"")
    factors: Optional[SessionServiceFactors] = None
    metadata: Optional[Dict[str, Union[StrictBytes, StrictStr]]] = Field(default=None, description="\"custom key value list\"")
    user_agent: Optional[SessionServiceUserAgent] = Field(default=None, alias="userAgent")
    expiration_date: Optional[datetime] = Field(default=None, description="\"time the session will be automatically invalidated\"", alias="expirationDate")

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SessionServiceSession from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of factors
        if self.factors:
            _dict['factors'] = self.factors.to_dict()
        # override the default output from pydantic by calling `to_dict()` of user_agent
        if self.user_agent:
            _dict['userAgent'] = self.user_agent.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SessionServiceSession from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "creationDate": obj.get("creationDate"),
            "changeDate": obj.get("changeDate"),
            "sequence": obj.get("sequence"),
            "factors": SessionServiceFactors.from_dict(obj["factors"]) if obj.get("factors") is not None else None,
            "metadata": obj.get("metadata"),
            "userAgent": SessionServiceUserAgent.from_dict(obj["userAgent"]) if obj.get("userAgent") is not None else None,
            "expirationDate": obj.get("expirationDate")
        })
        return _obj


